@@ -36,10 +36,8 @@ class CfnPipeline(
 ):
     """A CloudFormation ``AWS::DataPipeline::Pipeline``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::DataPipeline::Pipeline
+    :cloudformationResource: AWS::DataPipeline::Pipeline
     """
 
     def __init__(
@@ -48,12 +46,12 @@ class CfnPipeline(
         id: builtins.str,
         *,
         name: builtins.str,
-        parameter_objects: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["ParameterObjectProperty", aws_cdk.core.IResolvable]]],
+        parameter_objects: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable]]],
         activate: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         description: typing.Optional[builtins.str] = None,
-        parameter_values: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]]]] = None,
-        pipeline_objects: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]]]] = None,
-        pipeline_tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]]]] = None,
+        parameter_values: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]] = None,
+        pipeline_objects: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]] = None,
+        pipeline_tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]] = None,
     ) -> None:
         """Create a new ``AWS::DataPipeline::Pipeline``.
 
@@ -81,11 +79,10 @@ class CfnPipeline(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -116,7 +113,6 @@ class CfnPipeline(
     def name(self) -> builtins.str:
         """``AWS::DataPipeline::Pipeline.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-name
         """
         return jsii.get(self, "name")
@@ -129,10 +125,9 @@ class CfnPipeline(
     @jsii.member(jsii_name="parameterObjects")
     def parameter_objects(
         self,
-    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["ParameterObjectProperty", aws_cdk.core.IResolvable]]]:
+    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable]]]:
         """``AWS::DataPipeline::Pipeline.ParameterObjects``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parameterobjects
         """
         return jsii.get(self, "parameterObjects")
@@ -140,7 +135,7 @@ class CfnPipeline(
     @parameter_objects.setter # type: ignore
     def parameter_objects(
         self,
-        value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["ParameterObjectProperty", aws_cdk.core.IResolvable]]],
+        value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable]]],
     ) -> None:
         jsii.set(self, "parameterObjects", value)
 
@@ -151,7 +146,6 @@ class CfnPipeline(
     ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DataPipeline::Pipeline.Activate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-activate
         """
         return jsii.get(self, "activate")
@@ -168,7 +162,6 @@ class CfnPipeline(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DataPipeline::Pipeline.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-description
         """
         return jsii.get(self, "description")
@@ -181,10 +174,9 @@ class CfnPipeline(
     @jsii.member(jsii_name="parameterValues")
     def parameter_values(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]]]]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]]:
         """``AWS::DataPipeline::Pipeline.ParameterValues``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parametervalues
         """
         return jsii.get(self, "parameterValues")
@@ -192,7 +184,7 @@ class CfnPipeline(
     @parameter_values.setter # type: ignore
     def parameter_values(
         self,
-        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]]]],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]],
     ) -> None:
         jsii.set(self, "parameterValues", value)
 
@@ -200,10 +192,9 @@ class CfnPipeline(
     @jsii.member(jsii_name="pipelineObjects")
     def pipeline_objects(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]]]]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]]:
         """``AWS::DataPipeline::Pipeline.PipelineObjects``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelineobjects
         """
         return jsii.get(self, "pipelineObjects")
@@ -211,7 +202,7 @@ class CfnPipeline(
     @pipeline_objects.setter # type: ignore
     def pipeline_objects(
         self,
-        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]]]],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]],
     ) -> None:
         jsii.set(self, "pipelineObjects", value)
 
@@ -219,10 +210,9 @@ class CfnPipeline(
     @jsii.member(jsii_name="pipelineTags")
     def pipeline_tags(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]]]]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]]:
         """``AWS::DataPipeline::Pipeline.PipelineTags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelinetags
         """
         return jsii.get(self, "pipelineTags")
@@ -230,7 +220,7 @@ class CfnPipeline(
     @pipeline_tags.setter # type: ignore
     def pipeline_tags(
         self,
-        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]]]],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]],
     ) -> None:
         jsii.set(self, "pipelineTags", value)
 
@@ -256,7 +246,6 @@ class CfnPipeline(
             :param ref_value: ``CfnPipeline.FieldProperty.RefValue``.
             :param string_value: ``CfnPipeline.FieldProperty.StringValue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -271,7 +260,6 @@ class CfnPipeline(
         def key(self) -> builtins.str:
             """``CfnPipeline.FieldProperty.Key``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-key
             """
             result = self._values.get("key")
@@ -282,7 +270,6 @@ class CfnPipeline(
         def ref_value(self) -> typing.Optional[builtins.str]:
             """``CfnPipeline.FieldProperty.RefValue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-refvalue
             """
             result = self._values.get("ref_value")
@@ -292,7 +279,6 @@ class CfnPipeline(
         def string_value(self) -> typing.Optional[builtins.str]:
             """``CfnPipeline.FieldProperty.StringValue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-stringvalue
             """
             result = self._values.get("string_value")
@@ -320,7 +306,6 @@ class CfnPipeline(
             :param key: ``CfnPipeline.ParameterAttributeProperty.Key``.
             :param string_value: ``CfnPipeline.ParameterAttributeProperty.StringValue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -332,7 +317,6 @@ class CfnPipeline(
         def key(self) -> builtins.str:
             """``CfnPipeline.ParameterAttributeProperty.Key``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html#cfn-datapipeline-pipeline-parameterobjects-attribtues-key
             """
             result = self._values.get("key")
@@ -343,7 +327,6 @@ class CfnPipeline(
         def string_value(self) -> builtins.str:
             """``CfnPipeline.ParameterAttributeProperty.StringValue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html#cfn-datapipeline-pipeline-parameterobjects-attribtues-stringvalue
             """
             result = self._values.get("string_value")
@@ -377,7 +360,6 @@ class CfnPipeline(
             :param attributes: ``CfnPipeline.ParameterObjectProperty.Attributes``.
             :param id: ``CfnPipeline.ParameterObjectProperty.Id``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -391,7 +373,6 @@ class CfnPipeline(
         ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterAttributeProperty"]]]:
             """``CfnPipeline.ParameterObjectProperty.Attributes``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html#cfn-datapipeline-pipeline-parameterobjects-attributes
             """
             result = self._values.get("attributes")
@@ -402,7 +383,6 @@ class CfnPipeline(
         def id(self) -> builtins.str:
             """``CfnPipeline.ParameterObjectProperty.Id``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html#cfn-datapipeline-pipeline-parameterobjects-id
             """
             result = self._values.get("id")
@@ -431,7 +411,6 @@ class CfnPipeline(
             :param id: ``CfnPipeline.ParameterValueProperty.Id``.
             :param string_value: ``CfnPipeline.ParameterValueProperty.StringValue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -443,7 +422,6 @@ class CfnPipeline(
         def id(self) -> builtins.str:
             """``CfnPipeline.ParameterValueProperty.Id``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html#cfn-datapipeline-pipeline-parametervalues-id
             """
             result = self._values.get("id")
@@ -454,7 +432,6 @@ class CfnPipeline(
         def string_value(self) -> builtins.str:
             """``CfnPipeline.ParameterValueProperty.StringValue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html#cfn-datapipeline-pipeline-parametervalues-stringvalue
             """
             result = self._values.get("string_value")
@@ -490,7 +467,6 @@ class CfnPipeline(
             :param id: ``CfnPipeline.PipelineObjectProperty.Id``.
             :param name: ``CfnPipeline.PipelineObjectProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -505,7 +481,6 @@ class CfnPipeline(
         ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.FieldProperty"]]]:
             """``CfnPipeline.PipelineObjectProperty.Fields``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-fields
             """
             result = self._values.get("fields")
@@ -516,7 +491,6 @@ class CfnPipeline(
         def id(self) -> builtins.str:
             """``CfnPipeline.PipelineObjectProperty.Id``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-id
             """
             result = self._values.get("id")
@@ -527,7 +501,6 @@ class CfnPipeline(
         def name(self) -> builtins.str:
             """``CfnPipeline.PipelineObjectProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-name
             """
             result = self._values.get("name")
@@ -556,7 +529,6 @@ class CfnPipeline(
             :param key: ``CfnPipeline.PipelineTagProperty.Key``.
             :param value: ``CfnPipeline.PipelineTagProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -568,7 +540,6 @@ class CfnPipeline(
         def key(self) -> builtins.str:
             """``CfnPipeline.PipelineTagProperty.Key``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html#cfn-datapipeline-pipeline-pipelinetags-key
             """
             result = self._values.get("key")
@@ -579,7 +550,6 @@ class CfnPipeline(
         def value(self) -> builtins.str:
             """``CfnPipeline.PipelineTagProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html#cfn-datapipeline-pipeline-pipelinetags-value
             """
             result = self._values.get("value")
@@ -616,12 +586,12 @@ class CfnPipelineProps:
         self,
         *,
         name: builtins.str,
-        parameter_objects: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable]]],
+        parameter_objects: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[CfnPipeline.ParameterObjectProperty, aws_cdk.core.IResolvable]]],
         activate: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         description: typing.Optional[builtins.str] = None,
-        parameter_values: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]] = None,
-        pipeline_objects: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]] = None,
-        pipeline_tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]] = None,
+        parameter_values: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.ParameterValueProperty]]]] = None,
+        pipeline_objects: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.PipelineObjectProperty]]]] = None,
+        pipeline_tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.PipelineTagProperty]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::DataPipeline::Pipeline``.
 
@@ -633,7 +603,6 @@ class CfnPipelineProps:
         :param pipeline_objects: ``AWS::DataPipeline::Pipeline.PipelineObjects``.
         :param pipeline_tags: ``AWS::DataPipeline::Pipeline.PipelineTags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -655,7 +624,6 @@ class CfnPipelineProps:
     def name(self) -> builtins.str:
         """``AWS::DataPipeline::Pipeline.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-name
         """
         result = self._values.get("name")
@@ -665,10 +633,9 @@ class CfnPipelineProps:
     @builtins.property
     def parameter_objects(
         self,
-    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable]]]:
+    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[CfnPipeline.ParameterObjectProperty, aws_cdk.core.IResolvable]]]:
         """``AWS::DataPipeline::Pipeline.ParameterObjects``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parameterobjects
         """
         result = self._values.get("parameter_objects")
@@ -681,7 +648,6 @@ class CfnPipelineProps:
     ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DataPipeline::Pipeline.Activate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-activate
         """
         result = self._values.get("activate")
@@ -691,7 +657,6 @@ class CfnPipelineProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DataPipeline::Pipeline.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-description
         """
         result = self._values.get("description")
@@ -700,10 +665,9 @@ class CfnPipelineProps:
     @builtins.property
     def parameter_values(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.ParameterValueProperty]]]]:
         """``AWS::DataPipeline::Pipeline.ParameterValues``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parametervalues
         """
         result = self._values.get("parameter_values")
@@ -712,10 +676,9 @@ class CfnPipelineProps:
     @builtins.property
     def pipeline_objects(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.PipelineObjectProperty]]]]:
         """``AWS::DataPipeline::Pipeline.PipelineObjects``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelineobjects
         """
         result = self._values.get("pipeline_objects")
@@ -724,10 +687,9 @@ class CfnPipelineProps:
     @builtins.property
     def pipeline_tags(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.PipelineTagProperty]]]]:
         """``AWS::DataPipeline::Pipeline.PipelineTags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelinetags
         """
         result = self._values.get("pipeline_tags")
